@@ -102,7 +102,8 @@ def PrimeList(Max):
 
 def reverse(list_or_text):
     if type(list_or_text) is list:
-        return (list_or_text.reverse())
+        list_or_text.reverse()
+        return list_or_text
     else:
         return (list_or_text[::-1])
 
